using System.ComponentModel.DataAnnotations;
using System.Globalization;

namespace StarsAssistant.Model;

public class Game (string gamePath, string baseName)
{
    /// <summary>
    /// The base path in which all game files reside.
    /// </summary>
    public string GamePath { get; private set; } = gamePath;

    /// <summary>
    /// The base name without extensions of your game, inside the GamePath folder.
    /// All dependant files are resolved using this name.
    /// </summary>
    public string BaseName { get; private set; } = baseName;

    /// <summary>
    /// The number of the player, for example identifying the pxx planet file.
    /// </summary>
    public int PlayerId { get; private set; }

    /// <summary>
    /// Combine into the DatabaseName
    /// </summary>
    public string DatabaseName => Path.Combine(GamePath, $"{BaseName}.sqlite");

    /// <summary>
    /// Search for Planet files using this pattern, will give you all pxx files.
    /// </summary>
    public string PlanetFileSearchPattern => Path.Combine(GamePath, $"{BaseName}.p*");

}
